<?php

/* If the user can't edit theme options, no use running this plugin */

define( 'OPTIONS_FRAMEWORK_DIRECTORY', plugin_dir_url( __FILE__ ));

/**
* 言語ファイル設定
*/

load_textdomain('cp4-premium', dirname(__FILE__).'/languages/'.get_locale().'.mo');

require(dirname(__FILE__).'/options-config.php');
require(dirname(__FILE__).'/options-widgets.php');
require(dirname(__FILE__).'/options-install.php');
//require(dirname(__FILE__).'/options-debug.php');

add_action('init', 'optionsframework_rolescheck' );

function optionsframework_rolescheck () {

	if(current_user_can( 'edit_theme_options' ) ) {
		add_action('admin_menu', 'cp4_premium_theme_admin_add_page');
		add_action('admin_init', 'optionsframework_init');
		add_action('wp_before_admin_bar_render', 'optionsframework_adminbar');
	}
	
}

/**
 *　wp_optionに保存するテーブル名を設定
 */

function optionsframework_option_name() {

	$themename = 'theme-option';
	$themename = preg_replace("/\W/", "_", strtolower($themename));

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
	
}

/**
* Loads the file for option sanitization
*/

add_action('init', 'optionsframework_load_sanitization' );

function optionsframework_load_sanitization() {

	require_once(dirname( __FILE__ ).'/options-sanitize.php');
	
}

/* 
 * Creates the settings in the database by looping through the array
 * we supplied in options.php.  This is a neat way to do it since
 * we won't have to save settings for headers, descriptions, or arguments.
 *
 * Read more about the Settings API in the WordPress codex:
 * http://codex.wordpress.org/Settings_API
 *
 */

function optionsframework_init() {

	// Include the required files
	require(dirname(__FILE__).'/options-interface.php');
	require(dirname(__FILE__).'/options-medialibrary-uploader.php');
	require(dirname(__FILE__).'/options-crop.php');
	
	//** option.php　読み込み **//
	
	if($optionsfile = locate_template(array('options.php'))){
	
		require_once($optionsfile);
		
	}elseif(file_exists(dirname(__FILE__).'/options.php')){
	
		require_once dirname(__FILE__).'/options.php';
		
	}
	
	$optionsframework_settings = get_option('optionsframework' );
	
	// Updates the unique option id in the database if it has changed
	optionsframework_option_name();
	
	// Gets the unique id, returning a default if it isn't defined
	if(isset($optionsframework_settings['id'])){
	
		$option_name = $optionsframework_settings['id'];
		
	}else{
	
		$option_name = 'optionsframework';
	
	}
	
	// If the option has no saved data, load the defaults
	if ( ! get_option($option_name) ) {
		optionsframework_setdefaults();
	}
	
	// Registers the settings fields and callback
	register_setting( 'optionsframework', $option_name, 'optionsframework_validate' );
	
	// Change the capability required to save the 'optionsframework' options group.
	add_filter( 'option_page_capability_optionsframework', 'optionsframework_page_capability' );
}




/**
 * Ensures that a user with the 'edit_theme_options' capability can actually set the options
 * See: http://core.trac.wordpress.org/ticket/14365
 *
 * @param string $capability The capability used for the page, which is manage_options by default.
 * @return string The capability to actually use.
 */

function optionsframework_page_capability( $capability ) {
	return 'edit_theme_options';
}

/* 
 * Adds default options to the database if they aren't already present.
 * May update this later to load only on plugin activation, or theme
 * activation since most people won't be editing the options.php
 * on a regular basis.
 *
 * http://codex.wordpress.org/Function_Reference/add_option
 *
 */

function optionsframework_setdefaults() {
	
	$optionsframework_settings = get_option('optionsframework');
	
	
	// Gets the unique option id
	$option_name = $optionsframework_settings['id'];
	
	/* 
	 * Each theme will hopefully have a unique id, and all of its options saved
	 * as a separate option set.  We need to track all of these option sets so
	 * it can be easily deleted if someone wishes to remove the plugin and
	 * its associated data.  No need to clutter the database.  
	 *
	 */
	
	if ( isset($optionsframework_settings['knownoptions']) ) {
		$knownoptions =  $optionsframework_settings['knownoptions'];
		if ( !in_array($option_name, $knownoptions) ) {
			array_push( $knownoptions, $option_name );
			$optionsframework_settings['knownoptions'] = $knownoptions;
			update_option('optionsframework', $optionsframework_settings);
		}
	} else {
		$newoptionname = array($option_name);
		$optionsframework_settings['knownoptions'] = $newoptionname;
		update_option('optionsframework', $optionsframework_settings);
	}
	

	
	// Gets the default options data from the array in options.php
	if (function_exists('optionsframework_options')){
	
		$options = optionsframework_options();
	
	}
	
	// If the options haven't been added to the database yet, they are added now
	$values = of_get_default_values();
	
	if ( isset($values) ) {
		add_option( $option_name, $values ); // Add option with default settings
		
	}
}

/**
* 管理画面にメニューを追加
*/


if ( !function_exists('cp4_premium_theme_admin_add_page')){

	function cp4_premium_theme_admin_add_page(){
	
		$add_page_menu = add_theme_page(__('テーマカスタマイズ'), __('テーマカスタマイズ'), 'edit_theme_options', 'options-framework','optionsframework_page');
		
						
		// テーマオプションページにのみJSを出力
		add_action('admin_print_scripts-'.$add_page_menu, 'optionsframework_load_scripts');		
		
		// テーマオプションページにのみCSSを出力
		add_action('admin_print_styles-'.$add_page_menu, 'optionsframework_load_styles' );
		
	}
	
}

/**
* css読み込み
*/

// wp_head
function theme_enqueue_styles() {
	wp_enqueue_style('buttons-ui', OPTIONS_FRAMEWORK_DIRECTORY.'css/buttons.css');
}

add_action('wp_enqueue_scripts', 'theme_enqueue_styles');

function optionsframework_load_styles() {

	wp_enqueue_style('optionsframework', OPTIONS_FRAMEWORK_DIRECTORY . 'css/style.css');
	wp_enqueue_style('buttons-ui', OPTIONS_FRAMEWORK_DIRECTORY.'css/buttons.css');
	wp_enqueue_style( 'wp-color-picker' );
	
	//** tickbox css読み込み  **//
	wp_enqueue_style('thickbox');
	
	if(of_get_option('content_typography')){
	
		$content_typography = of_get_option('content_typography');	
		wp_enqueue_style('google_font','http://fonts.googleapis.com/css?family='.$content_typography['face']);

	}
		
}

/**
* javascript読み込み
*/

function optionsframework_load_scripts($hook) {

	
	wp_enqueue_script('json2');

	//** tickbox js読み込み  **//
	wp_enqueue_script('thickbox');
	
	if (!wp_script_is( 'wp-color-picker', 'registered' ) ) { //** 3.3以下はプラグインディレクトリから読み込み **//


	//** 古いカラーピッカーは使用しない **//
	

		wp_deregister_script('colorpicker');
		wp_deregister_script('jquery-color');
	
		wp_deregister_script('jquery-ui');
		wp_register_script('jquery-ui','https://ajax.googleapis.com/ajax/libs/jqueryui/1.10.2/jquery-ui.min.js');
		wp_enqueue_script('jquery-ui');
		
		wp_deregister_script('jquery-ui-widget');
		wp_enqueue_script('jquery-ui-widget',OPTIONS_FRAMEWORK_DIRECTORY .'js/ui/jquery.ui.widget.min.js', array('jquery-ui'));
		
		wp_deregister_script('jquery-ui-mouse');
		wp_enqueue_script('jquery-ui-mouse',OPTIONS_FRAMEWORK_DIRECTORY .'js/ui/jquery.ui.mouse.min.js', array('jquery-ui'));		
		
		wp_deregister_script('jquery-ui-draggable');
		wp_enqueue_script('jquery-ui-draggable',OPTIONS_FRAMEWORK_DIRECTORY .'js/ui/jquery.ui.draggable.min.js', array('jquery-ui'));
		
		wp_deregister_script('jquery-ui-slider');
		wp_enqueue_script('jquery-ui-slider',OPTIONS_FRAMEWORK_DIRECTORY .'js/ui/jquery.ui.slider.min.js', array('jquery-ui'));
		
		wp_enqueue_script('jquery-ui-touch-punch',OPTIONS_FRAMEWORK_DIRECTORY .'js/ui/jquery.ui.touch-punch.js', array('jquery-ui-core'));

		wp_register_script('iris',OPTIONS_FRAMEWORK_DIRECTORY .'js/iris.min.js',array('jquery'));
		wp_enqueue_script('iris');
		
		wp_enqueue_script('wp-color-picker',OPTIONS_FRAMEWORK_DIRECTORY.'js/color-picker.min.js',array('jquery','iris'));
		
		$colorpicker_l10n = array(
			'clear' => __('クリア'),
			'defaultString' => __('デフォルト'),
			'pick' => __('色を選択'),
			'current' => __('現在の色'),
		) ;
		
		wp_localize_script( 'wp-color-picker', 'wpColorPickerL10n', $colorpicker_l10n );

	}else{
	
		wp_deregister_script('jquery-ui');
		wp_register_script('jquery-ui','https://ajax.googleapis.com/ajax/libs/jqueryui/1.10.3/jquery-ui.min.js');
		wp_enqueue_script('jquery-ui');
		wp_enqueue_script('jquery-ui-core');
		wp_enqueue_script('jquery-ui-touch-punch');
		wp_enqueue_script('jquery-ui-tabs');
		wp_enqueue_script('wp-color-picker');
	
	}
	
	//** imege-edit ajax js読み込み  **//
	
	//wp_enqueue_script('wp-ajax-response');	
	//wp_enqueue_script('myplupload',OPTIONS_FRAMEWORK_DIRECTORY .'js/myplupload.js', array('jquery'));
		
	 /*$plupload_init = array(
        'runtimes' => 'html5,silverlight,flash,html4',
        'browse_button' => 'plupload-browse-button', // will be adjusted per uploader
        'container' => 'plupload-upload-ui', // will be adjusted per uploader
        'drop_element' => 'drag-drop-area', // will be adjusted per uploader
        'file_data_name' => 'async-upload', // will be adjusted per uploader
        'multiple_queues' => true,
        'max_file_size' => wp_max_upload_size().'b',
        'url' => admin_url('admin-ajax.php'),
        'flash_swf_url' => OPTIONS_FRAMEWORK_DIRECTORY.'js/plupload/plupload.flash.swf',
        'silverlight_xap_url' => OPTIONS_FRAMEWORK_DIRECTORY.'js/plupload/plupload.silverlight.xap',
        'filters' => array(array('title' => __('Allowed Files'), 'extensions' => '*')),
        'multipart' => true,
        'urlstream_upload' => true,
        'multi_selection' => false, // will be added per uploader
         // additional post data to send to our ajax hook
        'multipart_params' => array(
            '_ajax_nonce' => "", // will be added per uploader
            'action' => 'plupload_action', // the ajax action name
            'imgid' => 0, // will be added per uploader,
			'attachimentid' => 0
        )
    );
	

	$params = array('l10n_print_after' => 'var base_plupload_config = ' . json_encode($plupload_init) . ';');
 	wp_localize_script('myplupload','base_plupload',$params);
		 */
    
    wp_enqueue_media();
    
        // カスタムメディアアップローダー用のJavaScript
    wp_enqueue_script('cp4-media-uploader-fix',    plugins_url('js/cp4-media-uploader-fix.js', __FILE__),
        array('jquery'),'20171120',
        false
    );  
    wp_localize_script('cp4-media-uploader-fix','noimage', array('url' => OPTIONS_FRAMEWORK_DIRECTORY.'images/noimage.png'));
    
    wp_enqueue_script('wp-color-picker',OPTIONS_FRAMEWORK_DIRECTORY.'js/color-picker.min.js',array('jquery','iris'));
    
	wp_enqueue_script('menutabs',OPTIONS_FRAMEWORK_DIRECTORY .'js/menu_tabs.js', array('jquery-ui-tabs'),false,true);
		
	//** goolmemapAPI **//	
	
	wp_register_script('cp4_gmap','http://maps.googleapis.com/maps/api/js?sensor=false',array(),false,true);
    wp_enqueue_script('cp4_gmap');
	wp_register_script('cp4_gmap_config',OPTIONS_FRAMEWORK_DIRECTORY .'js/gmap.js',array('cp4_gmap'),'1.0',true);
    wp_enqueue_script('cp4_gmap_config');
	
	$gmap = of_get_option('gmaps');

	
	if(!empty($gmap['latlng'])){
	
		$latlng = explode(",",$gmap['latlng']);
	
	}else{
		
		$latlng = explode(",",'43.068590315922755,141.3507562950134'); //初期値	
	
	}
	
	wp_localize_script('cp4_gmap_config','gmap_vars', array('lat' =>  $latlng[0],'lng' => $latlng[1]));
	
	//** jquery.fontselect.js 読み込み **//
	
	wp_register_script('fontselect',OPTIONS_FRAMEWORK_DIRECTORY .'js/fontselect/jquery.fontselect.js', array('jquery'));
	wp_enqueue_script('fontselect');
	
	
	$content_typography = of_get_option('content_typography');		
	
	if($content_typography['face']){
			
		wp_enqueue_style('google_font','http://fonts.googleapis.com/css?family='.$content_typography);	
		wp_localize_script('fontselect','content_fontface', array('place' => $content_typography['face']));
	
	
	}else{
	
		wp_localize_script('fontselect','content_fontface', array('place' => '指定なし'));
	
	}
	

	//** 画像アップローダーajax読み込み **//
	
	wp_enqueue_script('plupload-all');
		

	// dropkick js　読み込み
	wp_enqueue_script('dropkick',OPTIONS_FRAMEWORK_DIRECTORY.'js/jquery.dropkick.js',array('jquery'));
	wp_enqueue_script('dropkick');
	
	// Enqueue custom option panel JS
	wp_register_script('options-custom', OPTIONS_FRAMEWORK_DIRECTORY.'js/options-custom.js',array('jquery'));
	wp_enqueue_script('options-custom');
	
	
	wp_register_script('jquery-cookie', OPTIONS_FRAMEWORK_DIRECTORY.'js/jquery.cookie.js',array('jquery-ui-tabs'),false,true);
	wp_enqueue_script('jquery-cookie');
	


	// Inline scripts from options-interface.php
	add_action( 'admin_head', 'of_admin_head' );
	
}

function of_admin_head() {
	// Hook to add custom scripts
	do_action( 'optionsframework_custom_scripts' );
}

/**
 * Init for render of an override widget admin page
 * @return void
 */
 
add_action('init','admin_page_include_menu');

function admin_page_include_menu(){

	global $pagenow;
	
	if ($pagenow == "widgets.php" || $pagenow == "nav-menus.php" || $_GET['page'] == "multi-device-switcher" || $_GET['page'] == "wp-table-reloaded" || $_GET['page'] == "cp4_connect/cp4-connect.php" || $_GET['page'] == 'cp4_connect_cast_edit' || $_GET['page'] == 'cp4_connect_cast_list' || $_GET['page'] == 'cp4_connect_cast_edit' || $_GET['page'] == 'cp4_connect_cast_schedule' || $_GET['page'] == 'cp4_connect_cast_schedule_timeline' || $_GET['page'] == 'cp4_connect_machihime' || $_GET['page'] == 'trust-form-edit') {
		
		add_action("admin_notices", 'admin_insert_cp4_menu', 100);
		wp_enqueue_style('optionsframework', OPTIONS_FRAMEWORK_DIRECTORY . 'css/style.css');
	}
	
}


function admin_insert_cp4_menu(){

	global $pagenow;
?>

	<div id="gantry-overrides">
		<div class="overrides-inner">
        <div class="overrides-cp4-menu">
        <!--
         <?php if($_GET['page'] != 'options-framework'){ ?>--><div class="overrides-menu"><a href="<?php echo get_admin_url(NULL,'themes.php?page=options-framework'); ?>"><span class="menu01"><?php _e('テーマカスタマイズ'); ?></span></a></div><!--	<?php } ?>			
        --><div class="overrides-menu"><a href="<?php echo get_admin_url(NULL,'widgets.php'); ?>" id="navi_widgets"><span class="menu01"><?php _e('ウィジェット設定'); ?></span></a></div><!--				
		--><div class="overrides-menu"><a href="<?php echo get_admin_url(NULL,'nav-menus.php'); ?>" id="navi_menu"><span class="menu02"><?php _e('メニュー設定'); ?></span></a></div><!--
		--><div class="overrides-menu"><a href="<?php echo get_admin_url(NULL,'admin.php?page=trust-form-edit'); ?>" id="navi_mailform"><span class="menu03"><?php _e('メールフォーム'); ?></span></a></div><!--
        --><div class="overrides-menu"><a href="<?php echo get_admin_url(NULL,'themes.php?page=multi-device-switcher'); ?>" id="navi_multidevice"><span class="menu04"><?php _e('マルチデバイス設定'); ?></span></a></div><!--
         --><div class="overrides-menu"><a href="<?php echo get_admin_url(NULL,'tools.php?page=wp-table-reloaded'); ?>" id="navi_table"><span class="menu05"><?php _e('テーブル作成'); ?></span></a></div><!--
        --><div class="overrides-menu"><a href="<?php echo get_admin_url(NULL,'admin.php?page=cp4_connect/cp4-connect.php'); ?>" id="navi_cp4"><span class="menu06"><?php _e('CASTPRO4'); ?></span></a></div><!--
        --><div class="overrides-menu"><a href="<?php echo get_admin_url(NULL,'customize.php'); ?>" id="navi_preview" target="_blank"><span class="menu07"><?php _e('オンラインプレビュー'); ?></span></a></div><!--
        --></div><!--
        
        <?php if($_GET['page'] == 'options-framework'){ ?>--><div class="overrides-submit"><input type="submit" class="button-primary submit" name="update" value="<?php esc_attr_e('設定を保存'); ?>" /></div><!--<?php } ?>
        
        --> 
		<div class="clear"></div>
		</div>

		</div>

<?php }

/* 
 * optionsframework_page
 */

if (!function_exists( 'optionsframework_page')){

	function optionsframework_page() {
		settings_errors();
		?>
        <div id="optionsframework-wrap" class="wrap">
		<?php screen_icon('themes'); ?> <h2><?php _e('テーマカスタマイズ'); ?></h2>
		<div id="form_save_messege" class="updated below-h2" style="display:none;"><p><?php _e('注:保存してください。'); ?></p></div>
        
        <div id="optionsframework" class="postbox">
        <form id="option_form" action="options.php" method="post">
        <?php admin_insert_cp4_menu(); ?>
        <div id="tabs">
		<ul id="main_tabs"><?php echo optionsframework_tabs(); ?></ul>
		<div id="optionsframework-metabox" class="metabox-holder">		        
		<?php settings_fields('optionsframework'); ?>
		<?php optionsframework_fields(); ?>            
		<div id="optionsframework-submit">
        <div class="overrides-submit">
		<input type="submit" class="button-primary" name="update" value="<?php esc_attr_e('設定を保存'); ?>" />
        </div>
		<div class="clear"></div>
		</div>		
		</div> <!-- / #container -->
		</div>
        </form>
	
    	<?php do_action('optionsframework_after'); ?>
	</div>
    	</div>
		<!-- / .wrap -->	
	<?php }

}

/**
 * Validate Options.
 *
 * This runs after the submit/reset button has been clicked and
 * validates the inputs.
 *
 * @uses $_POST['reset'] to restore default options
 */
function optionsframework_validate( $input ) {

	/*
	 * Restore Defaults.
	 *
	 * In the event that the user clicked the "Restore Defaults"
	 * button, the options defined in the theme's options.php
	 * file will be added to the option for the active theme.
	 */

	if ( isset( $_POST['reset'] ) ) {
		add_settings_error( 'options-framework', 'restore_defaults', __( 'Default options restored.', 'options_framework_theme' ), 'updated fade' );
		return of_get_default_values();
	}
	
	/*
	 * Update Settings
	 *
	 * This used to check for $_POST['update'], but has been updated
	 * to be compatible with the theme customizer introduced in WordPress 3.4
	 */
	 
	$clean = array();
	$options = optionsframework_options();
	foreach ( $options as $option ) {

		if (!isset( $option['id'][0])){
			continue;
		}

		if ( ! isset( $option['type'])){
			continue;
		}
		
			$id = preg_replace('/[^a-zA-Z0-9._\-]/','',$option['id'][0]);
		
		if($option['id']['child']){
				
			$child_id = preg_replace('/[^a-zA-Z0-9._\-]/','',$option['id']['child']);
		
		}
		
	
		if(is_array($input[$id])){
		
			$input_ID = $input[$id];				
			$child_ID = $input[$id]['child'];
		
		}else{
		
			$input_ID = $input[$id];
		
		}
		
		// Set checkbox to false if it wasn't sent in the $_POST
		
		if ( 'checkbox' == $option['type']){
		
			if(!isset($input[$id])){
			
				$input[$id] = false;
				
			}elseif(!isset($input[$id]['child'])){
			
				$input[$id]['child'] = false;
				
			}
			
		}		
		

		// Set each item in the multicheck to false if it wasn't sent in the $_POST
		if ( 'multicheck' == $option['type'] && ! isset( $input[$id] ) ) {
			foreach ( $option['options'] as $key => $value ) {
				$input[$id][$key] = false;
			}
		}

		// For a value to be submitted to database it must pass through a sanitization filter
		
		if(has_filter('of_sanitize_'.$option['type'])){
		
			if($option['id']['child']){
			
				$clean[$id][$child_id] = apply_filters('of_sanitize_' . $option['type'], $input[$id][$child_id], $option );
				
			}else{
			
				$clean[$id] = apply_filters( 'of_sanitize_' . $option['type'], $input[$id], $option );
				
			}					
			
		}
	}
	
	// Hook to run after validation
	do_action( 'optionsframework_after_validate', $clean );
	
	return $clean;
}

/**
 * Display message when options have been saved
 */
 
function optionsframework_save_options_notice() {
	add_settings_error( 'options-framework', 'save_options', __('設定を保存しました。'), 'updated fade' );
}

add_action( 'optionsframework_after_validate', 'optionsframework_save_options_notice' );

/**
 * Format Configuration Array.
 *
 * Get an array of all default values as set in
 * options.php. The 'id','std' and 'type' keys need
 * to be defined in the configuration array. In the
 * event that these keys are not present the option
 * will not be included in this function's output.
 *
 * @return    array     Rey-keyed options configuration array.
 *
 * @access    private
 */
 
function of_get_default_values() {
	$output = array();
	
	if (function_exists('optionsframework_options')){
	
		$config = optionsframework_options();
	
	}
	
	foreach ( (array) $config as $option ) {
		//if (!isset( $option['id'][0] ) ) {
			//continue;
		//}
		if ( ! isset( $option['std'] ) ) {
			continue;
		}
		if ( ! isset( $option['type'] ) ) {
			continue;
		}
		if ( has_filter( 'of_sanitize_' . $option['type'] ) ) {
		
			if($option['id']['child']){
			
				$child_id = preg_replace('/[^a-zA-Z0-9._\-]/','',$option['id']['child']);			
				$clean[$id][$child_id] = apply_filters( 'of_sanitize_' . $option['type'], $input[$id][$child_id], $option );
				
			}else{
			
				$clean[$id][0] = apply_filters( 'of_sanitize_' . $option['type'], $input[$id], $option );
				
			}
				
		}
	}
	return $output;
}

/**
 * Add Theme Options menu item to Admin Bar.
 */

function optionsframework_adminbar() {

	global $wp_admin_bar;

	$wp_admin_bar->add_menu( array(
			'parent' => 'appearance',
			'id' => 'of_theme_options',
			'title' => __('テーマオプション'),
			'href' => admin_url( 'themes.php?page=options-framework' )
		));
}

if ( ! function_exists( 'of_get_option' ) ) {

	/**
	 * Get Option.
	 *
	 * Helper function to return the theme option value.
	 * If no value has been saved, it returns $default.
	 * Needed because options are saved as serialized strings.
	 */
	 
	function of_get_option( $name, $default = false ) {
	
		$config = get_option( 'optionsframework' );

		if ( ! isset( $config['id'] ) ) {
			return $default;
		}

		$options = get_option( $config['id'] );

		if ( isset( $options[$name] ) ) {
			return $options[$name];
		}

		return $default;
	}
} ?>